==> caja-rename_24.4.1.orig.tar.gz: caja-rename-24.4.1/CHANGELOG.md <==
# 24.4.1

 - Translated using Weblate (Chinese (Simplified)) (a0e4550)

# 24.2.1

 - Translated using Weblate (Portuguese) (2b5c484)
 - Translated using Weblate (Arabic) (4d7b5d8)

# 23.12.1

 - Translated using Weblate (Ukrainian) (3afb34d)
 - Added translation using Weblate (Ukrainian) (f0612ab)

# 23.11.1

 - Translated using Weblate (Turkish) (eee5f1a)
 - Translated using Weblate (German) (1c7e5c5)
 - Translated using Weblate (Czech) (fec3ff7)
 - Translated using Weblate (Croatian) (3a97b6b)
 - Translated using Weblate (Russian) (4ff86a4)
 - Translated using Weblate (Spanish) (dbec466)

# 23.10.1

 - Restore README and COPYING (cf4da5c)
 - Rewrite in C (da3af00)

# 23.9.1

 - po/cajarename.pot: Update translation template (202582a)
 - data/usr/share/cajarename/cajarename.glade: Fix dialog button image and label (eafdc9f)

# 23.8.1

 - Allow negative start index when removing part of file name (9c200c8)

# 23.7.1

 - Translated using Weblate (Turkish) (33c4d6a)
 - Added translation using Weblate (Turkish) (82cc575)

# 23.4.1

 - Translated using Weblate (Portuguese) (89de303)
 - Added translation using Weblate (Portuguese) (eb01f80)
 - debian/*: Update files (eb9e25e)
 - setup.py: Update translation file search strategy (faafb6a)
 - Translated using Weblate (Russian) (93e497a)
 - Added translation using Weblate (Russian) (2165aa8)
 - Translated using Weblate (French) (c9c5365)
 - Translated using Weblate (Portuguese (Brazil)) (5c11de7)
 - Translated using Weblate (Arabic) (0070e03)
 - Translated using Weblate (English (United Kingdom)) (4f81bec)

# Release 22.10.31

 - Translated using Weblate (Norwegian Bokmål) (3c0d8d8)
 - Translated using Weblate (Spanish) (e232bd5)
 - Translated using Weblate (Catalan) (f4d079d)
 - Translated using Weblate (Spanish) (1110e79)
 - Translated using Weblate (Spanish) (0d184b6)
 - Translated using Weblate (Lithuanian) (b82c30f)
 - Translated using Weblate (Czech) (18afdeb)

# Release 22.6.29

 - Translated using Weblate (German) (b15c1d2)
 - Update translation files (bfd6a55)
 - Translated using Weblate (Arabic) (168df78)
 - Added translation using Weblate (Arabic) (34e0eed)
 - Translated using Weblate (Chinese (Simplified)) (093e13d)
 - Translated using Weblate (Chinese (Simplified)) (ed5517a)
 - Translated using Weblate (Chinese (Simplified)) (ce21dc6)

# Release 21.11.24

 - Use named icons with fallback (a98fa7a)
 - Translated using Weblate (Chinese (Simplified)) (bc8b282)

# Release 21.11.13

 - Translated using Weblate (Greek) (fe559d8)
 - Added translation using Weblate (Greek) (bf0e8ec)
 - Translated using Weblate (Chinese (Simplified)) (878a167)
 - Added translation using Weblate (Chinese (Simplified)) (dd5f51c)

# Release 21.7.18

 - Merge pull request #4 from tormodvolden/init_obj (cf54b56)
 - Avoid RuntimeError about object not initialized (c845426)
 - Translated using Weblate (Croatian) (659faa8)
 - Added translation using Weblate (Croatian) (926b497)

# Release 21.4.11

 - po/cajarename.pot: Update translation strings (9766484)
 - data/usr/share/caja-python/extensions/caja-rename.py: Rename menu item (fdff88d)
 - Translated using Weblate (Catalan) (bbcb569)
 - Translated using Weblate (Spanish) (b953be1)
 - Added translation using Weblate (Catalan) (ce4421f)
 - Translated using Weblate (Lithuanian) (c3f3503)
 - Translated using Weblate (Portuguese (Brazil)) (cec2629)
 - Translated using Weblate (Occitan) (61cdb3e)
 - Translated using Weblate (Occitan) (106d8d2)
 - Added translation using Weblate (Occitan) (da2a9f9)
 - Translated using Weblate (French) (bc971af)
 - Translated using Weblate (Norwegian Bokmål) (c603ea6)
 - Added translation using Weblate (French) (966df64)
 - Added translation using Weblate (Norwegian Bokmål) (c832833)
 - Add binary dir (c381a3d)
 - Version bump (cf5256a)
 - Initial port from Launchpad (2ebf946)

==> caja-rename_24.5.1.orig.tar.gz: caja-rename-24.5.1/CHANGELOG.md <==
# 24.5.1

 - Translated using Weblate (Hungarian) (f4635f9)
 - Added translation using Weblate (Hungarian) (4b56629)

# 24.4.1

 - Translated using Weblate (Chinese (Simplified)) (a0e4550)

# 24.2.1

 - Translated using Weblate (Portuguese) (2b5c484)
 - Translated using Weblate (Arabic) (4d7b5d8)

# 23.12.1

 - Translated using Weblate (Ukrainian) (3afb34d)
 - Added translation using Weblate (Ukrainian) (f0612ab)

# 23.11.1

 - Translated using Weblate (Turkish) (eee5f1a)
 - Translated using Weblate (German) (1c7e5c5)
 - Translated using Weblate (Czech) (fec3ff7)
 - Translated using Weblate (Croatian) (3a97b6b)
 - Translated using Weblate (Russian) (4ff86a4)
 - Translated using Weblate (Spanish) (dbec466)

# 23.10.1

 - Restore README and COPYING (cf4da5c)
 - Rewrite in C (da3af00)

# 23.9.1

 - po/cajarename.pot: Update translation template (202582a)
 - data/usr/share/cajarename/cajarename.glade: Fix dialog button image and label (eafdc9f)

# 23.8.1

 - Allow negative start index when removing part of file name (9c200c8)

# 23.7.1

 - Translated using Weblate (Turkish) (33c4d6a)
 - Added translation using Weblate (Turkish) (82cc575)

# 23.4.1

 - Translated using Weblate (Portuguese) (89de303)
 - Added translation using Weblate (Portuguese) (eb01f80)
 - debian/*: Update files (eb9e25e)
 - setup.py: Update translation file search strategy (faafb6a)
 - Translated using Weblate (Russian) (93e497a)
 - Added translation using Weblate (Russian) (2165aa8)
 - Translated using Weblate (French) (c9c5365)
 - Translated using Weblate (Portuguese (Brazil)) (5c11de7)
 - Translated using Weblate (Arabic) (0070e03)
 - Translated using Weblate (English (United Kingdom)) (4f81bec)

# Release 22.10.31

 - Translated using Weblate (Norwegian Bokmål) (3c0d8d8)
 - Translated using Weblate (Spanish) (e232bd5)
 - Translated using Weblate (Catalan) (f4d079d)
 - Translated using Weblate (Spanish) (1110e79)
 - Translated using Weblate (Spanish) (0d184b6)
 - Translated using Weblate (Lithuanian) (b82c30f)
 - Translated using Weblate (Czech) (18afdeb)

# Release 22.6.29

 - Translated using Weblate (German) (b15c1d2)
 - Update translation files (bfd6a55)
 - Translated using Weblate (Arabic) (168df78)
 - Added translation using Weblate (Arabic) (34e0eed)
 - Translated using Weblate (Chinese (Simplified)) (093e13d)
 - Translated using Weblate (Chinese (Simplified)) (ed5517a)
 - Translated using Weblate (Chinese (Simplified)) (ce21dc6)

# Release 21.11.24

 - Use named icons with fallback (a98fa7a)
 - Translated using Weblate (Chinese (Simplified)) (bc8b282)

# Release 21.11.13

 - Translated using Weblate (Greek) (fe559d8)
 - Added translation using Weblate (Greek) (bf0e8ec)
 - Translated using Weblate (Chinese (Simplified)) (878a167)
 - Added translation using Weblate (Chinese (Simplified)) (dd5f51c)

# Release 21.7.18

 - Merge pull request #4 from tormodvolden/init_obj (cf54b56)
 - Avoid RuntimeError about object not initialized (c845426)
 - Translated using Weblate (Croatian) (659faa8)
 - Added translation using Weblate (Croatian) (926b497)

# Release 21.4.11

 - po/cajarename.pot: Update translation strings (9766484)
 - data/usr/share/caja-python/extensions/caja-rename.py: Rename menu item (fdff88d)
 - Translated using Weblate (Catalan) (bbcb569)
 - Translated using Weblate (Spanish) (b953be1)
 - Added translation using Weblate (Catalan) (ce4421f)
 - Translated using Weblate (Lithuanian) (c3f3503)
 - Translated using Weblate (Portuguese (Brazil)) (cec2629)
 - Translated using Weblate (Occitan) (61cdb3e)
 - Translated using Weblate (Occitan) (106d8d2)
 - Added translation using Weblate (Occitan) (da2a9f9)
 - Translated using Weblate (French) (bc971af)
 - Translated using Weblate (Norwegian Bokmål) (c603ea6)
 - Added translation using Weblate (French) (966df64)
 - Added translation using Weblate (Norwegian Bokmål) (c832833)
 - Add binary dir (c381a3d)
 - Version bump (cf5256a)
 - Initial port from Launchpad (2ebf946)
